@@ -1,27 +1,31 @@
 from argparse import ArgumentParser
 from dataclasses import dataclass
+from typing import List
 
 
 @dataclass(init=False)
 class Arguments:
-    url: str = None
-    artist: str = None
-    album: str = None
+    url: str
+    artists: List[str]
+    album: str
 
     def __init__(self, argv=None):
         parser = ArgumentParser(
             description="Command-line program to download music from YouTube and other websites."
         )
         parser.add_argument("url", help="URL of the song/album to download")
-        parser.add_argument("--artist", help="artist name")
+        parser.add_argument(
+            "--artists",
+            help="comma-separated artists names"
+            ' like "Louis Armstrong,Ella Fitzgerald"',
+            type=lambda s: [name for name in s.split(",")],
+        )
         parser.add_argument("--album", help="album name")
 
         args = parser.parse_args(argv)
         self.url = args.url
-        if args.artist:
-            self.artist = args.artist
-        if args.album:
-            self.album = args.album
+        self.artists = args.artists or []
+        self.album = args.album
 
     def check(self):
         """
