@@ -11,7 +11,14 @@ class Downloader:
     def download(self):
         shutil.rmtree(TMP_DIR, ignore_errors=True)
         try:
-            ytdlp(["-x", "-o", TMP_DIR + r"%(title)s.%(ext)s", self.args.url])
+            ytdlp(
+                [
+                    "-x",
+                    "-o",
+                    TMP_DIR + r"%(playlist_index)s_%(title)s.%(ext)s",
+                    self.args.url,
+                ]
+            )
         except SystemExit as e:
             if e.code != 0:
                 raise e
